package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWz;
import com.ruoyi.tcZz.service.ITcWzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网站Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/wz")
public class TcWzController extends BaseController
{
    @Autowired
    private ITcWzService tcWzService;

    /**
     * 查询网站列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcWz tcWz)
    {
        startPage();
        List<TcWz> list = tcWzService.selectTcWzList(tcWz);
        return getDataTable(list);
    }

    /**
     * 导出网站列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:export')")
    @Log(title = "网站", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWz tcWz)
    {
        List<TcWz> list = tcWzService.selectTcWzList(tcWz);
        ExcelUtil<TcWz> util = new ExcelUtil<TcWz>(TcWz.class);
        util.exportExcel(response, list, "网站数据");
    }

    /**
     * 获取网站详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWzService.selectTcWzById(id));
    }

    /**
     * 新增网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:add')")
    @Log(title = "网站", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcWz tcWz)
    {
        return toAjax(tcWzService.insertTcWz(tcWz));
    }

    /**
     * 修改网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:edit')")
    @Log(title = "网站", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcWz tcWz)
    {
        return toAjax(tcWzService.updateTcWz(tcWz));
    }

    /**
     * 删除网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:wz:remove')")
    @Log(title = "网站", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWzService.deleteTcWzByIds(ids));
    }
}
